# Contributing to QuickWeb

## Filing issues

When filing an issue, make sure to answer these five questions:

1. What version of QW are you using « check `quickweb --version`» ?
2. What operating system are you using?
3. What did you do?
4. What did you expect to see?
5. What did you see instead?
